==> scansdk-1.1.2-sources.jar: cn/com/startai/scansdk/ChargerScanActivity.java <==
package cn.com.startai.scansdk;

import android.Manifest;
import android.app.Activity;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.os.Build;
import android.os.Bundle;
import android.os.Vibrator;
import android.provider.MediaStore;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.annotation.RequiresApi;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.ImageView;
import android.widget.Toast;
import android.widget.ToggleButton;

import com.blankj.utilcode.util.ToastUtils;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.Result;
import com.google.zxing.client.result.ParsedResult;
import com.mylhyl.zxing.scanner.OnScannerCompletionListener;
import com.mylhyl.zxing.scanner.ScannerOptions;
import com.mylhyl.zxing.scanner.ScannerView;
import com.mylhyl.zxing.scanner.decode.QRDecode;

import cn.com.startai.scansdk.permission.PermissionHelper;


/**
 * Created by Robin on 2018/3/1.
 * qq: 419109715 彬影
 */

public class ChargerScanActivity extends AppCompatActivity implements
        OnScannerCompletionListener {

    public static final String EXTRA_LASER_LINE_MODE = "extra_laser_line_mode";
    public static final String EXTRA_SCAN_MODE = "extra_scan_mode";
    public static final String EXTRA_SHOW_THUMBNAIL = "EXTRA_SHOW_THUMBNAIL";
    public static final String EXTRA_SCAN_FULL_SCREEN = "EXTRA_SCAN_FULL_SCREEN";
    public static final String EXTRA_HIDE_LASER_FRAME = "EXTRA_HIDE_LASER_FRAME";


    public static final int EXTRA_LASER_LINE_MODE_0 = 0;//线条图
    public static final int EXTRA_LASER_LINE_MODE_1 = 1;//网格图
    public static final int EXTRA_LASER_LINE_MODE_2 = 2;//线


    public static final int EXTRA_SCAN_MODE_0 = 0;//全部
    public static final int EXTRA_SCAN_MODE_1 = 1;//仅二维
    public static final int EXTRA_SCAN_MODE_2 = 2;//仅一维

    public static final int APPLY_READ_EXTERNAL_STORAGE = 0x111;

    private ScannerView mScannerView;
    private Result mLastResult;
    private String TAG = ChargerScanActivity.class.getSimpleName();


    private boolean showThumbnail;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_scanner_charger);
        com.blankj.utilcode.util.Utils.init(this);

        ImageView ivBack = (ImageView) findViewById(R.id.iv_back_charger);
        ivBack.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                ChargerScanActivity.this.finish();
            }
        });


        ToggleButton toggleButton = (ToggleButton) findViewById(R.id.toggleButton_charger);
        toggleButton.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                mScannerView.toggleLight(isChecked);
            }
        });

        mScannerView = (ScannerView) findViewById(R.id.scanner_view_charger);

        mScannerView.setOnScannerCompletionListener(this);

//        mScannerView.toggleLight(true);

        ScannerOptions.Builder builder = new ScannerOptions.Builder();
        builder.setFrameSize(256, 256)
                .setFrameCornerLength(22)
                .setFrameCornerWidth(2)
                .setFrameCornerInside(false)

//                .setLaserLineColor(0xff06c1ae)
//                .setLaserLineHeight(18)

                .setLaserStyle(ScannerOptions.LaserStyle.RES_LINE, R.mipmap.wx_scan_line_yellow)
//                .setLaserStyle(ScannerOptions.LaserStyle.RES_GRID, R.mipmap.zfb_grid_scan_line)//网格图

                .setFrameCornerColor(Color.parseColor("#FFF5D822"))//扫描框颜色

                .setScanFullScreen(false)

                .setFrameHide(true) //扫描框边线
//                .setFrameCornerHide(false)
//                .setLaserMoveFullScreen(false)
//                .setFrameOutsideColor(0xFF808080)
//                .setViewfinderCallback(new ScannerOptions.ViewfinderCallback() {
//                    @Override
//                    public void onDraw(View view, Canvas canvas, Rect frame) {
//                        Bitmap bmp = BitmapFactory.decodeResource(getResources(), R.mipmap.connect_logo);
//                        canvas.drawBitmap(bmp, frame.right / 2, frame.top - bmp.getHeight(), null);
//                    }
//                })
//                .setCameraZoomRatio(2)
                .setMediaResId(R.raw.baidu_beep)
                .setScanMode(BarcodeFormat.QR_CODE)
                .setTipText(getString(R.string.please_scan))
                .setTipTextSize(16)
                .setTipTextColor(getResources().getColor(R.color.color_gray));


        mScannerView.setScannerOptions(builder.build());

    }

    @Override
    public void onScannerCompletion(Result rawResult, ParsedResult parsedResult, Bitmap barcode) {

        if (rawResult == null) {
            Log.e(TAG, "no bacode find " + rawResult.getText());
            finish();
            return;
        }

        vibrate();

        mScannerView.restartPreviewAfterDelay(1000);

        Intent intent = new Intent(ChargerScanActivity.this, ChargerScanActivity.class);
        intent.putExtra("result", rawResult.getText());
        setResult(RESULT_OK, intent);
        finish();

    }

    private void vibrate() {
        Vibrator vibrator = (Vibrator) getSystemService(VIBRATOR_SERVICE);
        vibrator.vibrate(200);
    }


    @Override
    protected void onResume() {
        mScannerView.onResume();
        super.onResume();
    }

    @Override
    protected void onPause() {
        mScannerView.onPause();
        super.onPause();
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        switch (keyCode) {
            case KeyEvent.KEYCODE_BACK:
                if (mLastResult != null) {
                    restartPreviewAfterDelay(0L);
                    return true;
                }
                break;
        }
        return super.onKeyDown(keyCode, event);
    }


    private void restartPreviewAfterDelay(long delayMS) {
        mScannerView.restartPreviewAfterDelay(delayMS);
    }


    public static void showActivityForResult(final Activity act, final int requestCode) {
        com.blankj.utilcode.util.Utils.init(act);
        PermissionHelper.requestCamara(new PermissionHelper.OnPermissionGrantedListener() {
            @Override
            public void onPermissionGranted() {

                Intent intent = new Intent(act, ChargerScanActivity.class);
                act.startActivityForResult(intent, requestCode);

            }
        }, new PermissionHelper.OnPermissionDeniedListener() {
            @Override
            public void onPermissionDenied() {
                ToastUtils.showShort(R.string.please_authorize);
            }
        });


    }

}

==> scansdk-1.1.9-sources.jar: cn/com/startai/scansdk/ChargerScanActivity.java <==
package cn.com.startai.scansdk;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.hardware.Camera;
import android.os.Bundle;
import android.os.Vibrator;
import android.support.annotation.Nullable;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.ImageView;
import android.widget.ToggleButton;

import com.blankj.utilcode.util.ToastUtils;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.Result;
import com.google.zxing.client.result.ParsedResult;
import com.mylhyl.zxing.scanner.OnScannerCompletionListener;
import com.mylhyl.zxing.scanner.ScannerOptions;
import com.mylhyl.zxing.scanner.ScannerView;

import cn.com.startai.scansdk.permission.PermissionHelper;


/**
 * Created by Robin on 2018/3/1.
 * qq: 419109715 彬影
 */

public class ChargerScanActivity extends BaseActivity implements
        OnScannerCompletionListener {

    public static final String EXTRA_SCAN_CONFIG = "scanConfig";

    public static final String EXTRA_LASER_LINE_MODE = "extra_laser_line_mode";
    public static final String EXTRA_SCAN_MODE = "extra_scan_mode";
    public static final String EXTRA_SHOW_THUMBNAIL = "EXTRA_SHOW_THUMBNAIL";
    public static final String EXTRA_SCAN_FULL_SCREEN = "EXTRA_SCAN_FULL_SCREEN";
    public static final String EXTRA_HIDE_LASER_FRAME = "EXTRA_HIDE_LASER_FRAME";


    public static final int EXTRA_LASER_LINE_MODE_0 = 0;//线条图
    public static final int EXTRA_LASER_LINE_MODE_1 = 1;//网格图
    public static final int EXTRA_LASER_LINE_MODE_2 = 2;//线


    public static final int EXTRA_SCAN_MODE_0 = 0;//全部
    public static final int EXTRA_SCAN_MODE_1 = 1;//仅二维
    public static final int EXTRA_SCAN_MODE_2 = 2;//仅一维

    public static final int APPLY_READ_EXTERNAL_STORAGE = 0x111;

    private ScannerView mScannerView;
    private Result mLastResult;
    private String TAG = ChargerScanActivity.class.getSimpleName();


    private boolean showThumbnail;

    private ScanConfig scanConfig;
    private ToggleButton toggleButton;


    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_scanner_charger);
        com.blankj.utilcode.util.Utils.init(this);

        Intent intent = getIntent();
        if (intent != null) {
            scanConfig = (ScanConfig) intent.getSerializableExtra(EXTRA_SCAN_CONFIG);
        }
        if (scanConfig == null) {
            scanConfig = new ScanConfig();
        }

        ImageView ivBack = (ImageView) findViewById(R.id.iv_back_charger);
        ivBack.setImageResource(scanConfig.getResBackIcon());
        ivBack.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                closeLight();
                ChargerScanActivity.this.finish();
            }
        });


        toggleButton = (ToggleButton) findViewById(R.id.toggleButton_charger);

        toggleButton.setBackgroundDrawable(getResources().getDrawable(scanConfig.getResFlashlightOff()));


        toggleButton.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {

                mScannerView.toggleLight(isChecked);
                if (isChecked) {
                    buttonView.setBackgroundDrawable(getResources().getDrawable(scanConfig.getResFlashlightOn()));
                } else {
                    buttonView.setBackgroundDrawable(getResources().getDrawable(scanConfig.getResFlashlightOff()));
                }


            }
        });

        mScannerView = (ScannerView) findViewById(R.id.scanner_view_charger);

        mScannerView.setOnScannerCompletionListener(this);
//        mScannerView.toggleLight(true);

        ScannerOptions.Builder builder = new ScannerOptions.Builder();
        builder.setFrameSize(256, 256)
                .setFrameCornerLength(22)
                .setFrameCornerWidth(2)
                .setFrameCornerInside(false)

//                .setLaserLineColor(0xff06c1ae)
//                .setLaserLineHeight(18)

                .setLaserStyle(ScannerOptions.LaserStyle.RES_LINE, scanConfig.getResScanLine())
//                .setLaserStyle(ScannerOptions.LaserStyle.RES_GRID, R.mipmap.zfb_grid_scan_line)//网格图

                .setFrameCornerColor(Color.parseColor(scanConfig.getScanHexColor()))//扫描框颜色

                .setScanFullScreen(false)

                .setFrameHide(true) //扫描框边线
//                .setFrameCornerHide(false)
//                .setLaserMoveFullScreen(false)
//                .setFrameOutsideColor(0xFF808080)
//                .setViewfinderCallback(new ScannerOptions.ViewfinderCallback() {
//                    @Override
//                    public void onDraw(View view, Canvas canvas, Rect frame) {
//                        Bitmap bmp = BitmapFactory.decodeResource(getResources(), R.mipmap.connect_logo);
//                        canvas.drawBitmap(bmp, frame.right / 2, frame.top - bmp.getHeight(), null);
//                    }
//                })
//                .setCameraZoomRatio(2)
                .setMediaResId(R.raw.baidu_beep)
                .setScanMode(BarcodeFormat.QR_CODE)
                .setTipText(getString(R.string.please_scan))
                .setTipTextSize(16)
                .setTipTextColor(getResources().getColor(R.color.color_gray));


        mScannerView.setScannerOptions(builder.build());

    }

    @Override
    public void onScannerCompletion(Result rawResult, ParsedResult parsedResult, Bitmap barcode) {

        if (rawResult == null) {
            Log.e(TAG, "no bacode find " + rawResult.getText());
            finish();
            return;
        }

        vibrate();

        mScannerView.restartPreviewAfterDelay(1000);

        Intent intent = new Intent(ChargerScanActivity.this, ChargerScanActivity.class);
        intent.putExtra("result", rawResult.getText());
        setResult(RESULT_OK, intent);
        finish();

    }

    private void vibrate() {
        Vibrator vibrator = (Vibrator) getSystemService(VIBRATOR_SERVICE);
        vibrator.vibrate(200);
    }


    @Override
    protected void onResume() {
        try {

            mScannerView.onResume();
        } catch (Exception e) {
            e.printStackTrace();
            Log.e(TAG, "camera init failed");
            showCameraInitFailedDialog();
        }

        super.onResume();
    }

    @Override
    protected void onPause() {
        try {
            mScannerView.onPause();
        } catch (Exception e) {
            e.printStackTrace();
        }
        super.onPause();
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        switch (keyCode) {
            case KeyEvent.KEYCODE_BACK:
                if (mLastResult != null) {
                    restartPreviewAfterDelay(0L);
                    return true;
                }
                closeLight();
                break;
        }
        return super.onKeyDown(keyCode, event);
    }

    private void closeLight() {
        toggleButton.setChecked(false);
        toggleButton.setBackgroundDrawable(getResources().getDrawable(scanConfig.getResFlashlightOff()));
        mScannerView.toggleLight(false);
    }

    private void restartPreviewAfterDelay(long delayMS) {
        try {
            mScannerView.restartPreviewAfterDelay(delayMS);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void showActivityForResult(final Activity act, final int requestCode, final ScanConfig scanConfig) {

        com.blankj.utilcode.util.Utils.init(act.getApplication());
        PermissionHelper.requestCamara(new PermissionHelper.OnPermissionGrantedListener() {
            @Override
            public void onPermissionGranted() {

                Intent intent = new Intent(act, ChargerScanActivity.class);
                intent.putExtra(EXTRA_SCAN_CONFIG, scanConfig);
                act.startActivityForResult(intent, requestCode);

            }
        }, new PermissionHelper.OnPermissionDeniedListener() {
            @Override
            public void onPermissionDenied() {
                ToastUtils.showShort(R.string.please_authorize);
            }
        });

    }

    public static void showActivityForResult(final Activity act, final int requestCode) {
        com.blankj.utilcode.util.Utils.init(act.getApplication());
        PermissionHelper.requestCamara(new PermissionHelper.OnPermissionGrantedListener() {
            @Override
            public void onPermissionGranted() {

                Intent intent = new Intent(act, ChargerScanActivity.class);
                act.startActivityForResult(intent, requestCode);

            }
        }, new PermissionHelper.OnPermissionDeniedListener() {
            @Override
            public void onPermissionDenied() {
                ToastUtils.showShort(R.string.please_authorize);
            }
        });


    }

}
